import { BulkUpdateServiceHook } from "../types/bulk-update-service-hook-type";
import { CreateServiceHook } from "../types/create-service-hook-type";
import { DeleteServiceHook } from "../types/delete-service-hook-type";
import { GetServiceHook } from "../types/get-service-hook-type";
import { ListServiceHook } from "../types/list-service-hook-type";
import { NestedCreateServiceHook } from "../types/nested-create-service-hook-type";
import { NestedListServiceHook } from "../types/nested-list-service-hook-type";
import { UpdateServiceHook } from "../types/update-service-hook-type";
/**
 * Factory to encapsulate common service function logic
 */
declare const ServiceHookFactory: {
    /**
     * Creates conventional hook for using service update function for an array of the supplied resource type.
     * Automatically handles cancellation tokens internally.
     * @param recordType
     * @param resourceEndpoint
     */
    useBulkUpdate<TRecord, TPathParams>(recordType: new () => TRecord, resourceEndpoint: string): BulkUpdateServiceHook<TRecord, TPathParams>;
    /**
     * Creates conventional hook for using service create function for the supplied resource type.
     * Automatically handles cancellation tokens internally.
     *
     * ### Recommendation
     * Use `useNestedCreate` when route is nested!
     *
     * @param recordType
     * @param baseEndpoint
     */
    useCreate<TRecord_1 extends any>(recordType: new () => TRecord_1, baseEndpoint: string): CreateServiceHook<TRecord_1>;
    /**
     * Creates conventional hook for using service delete function for the supplied resource type.
     * Automatically handles cancellation tokens internally.
     * @param recordType
     * @param baseEndpoint
     */
    useDelete(resourceEndpoint: string): DeleteServiceHook;
    /**
     * Creates conventional hook for using service get function for the supplied resource type.
     * Automatically handles cancellation tokens internally.
     * @param recordType
     * @param resourceEndpoint
     */
    useGet<TRecord_2, TPathParams_1, TQueryParams = undefined>(recordType: new () => TRecord_2, resourceEndpoint: string): GetServiceHook<TRecord_2, TPathParams_1, TQueryParams>;
    /**
     * Creates conventional hook for using service list function for the supplied resource type.
     * Automatically handles cancellation tokens internally.
     *
     * ### Recommendation
     * Use `useNestedList` when route is nested!
     *
     * @param recordType
     * @param baseEndpoint
     */
    useList<TRecord_3, TQueryParams_1>(recordType: new () => TRecord_3, baseEndpoint: string): ListServiceHook<TRecord_3, TQueryParams_1>;
    /**
     * Creates conventional hook for using service nested create function for the supplied resource type.
     * Automatically handles cancellation tokens internally.
     * @param recordType
     * @param baseEndpoint
     */
    useNestedCreate<TRecord_4 extends any, TPathParams_2>(recordType: new () => TRecord_4, baseEndpoint: string): NestedCreateServiceHook<TRecord_4, TPathParams_2>;
    /**
     * Creates conventional hook for using service nested list function for the supplied resource type.
     * Automatically handles cancellation tokens internally.
     * @param recordType
     * @param baseEndpoint
     */
    useNestedList<TRecord_5, TPathParams_3, TQueryParams_2>(recordType: new () => TRecord_5, baseEndpoint: string): NestedListServiceHook<TRecord_5, TPathParams_3, TQueryParams_2>;
    /**
     * Creates conventional hook for using service update function for the supplied resource type.
     * Automatically handles cancellation tokens internally.
     * @param recordType
     * @param baseEndpoint
     */
    useUpdate<TRecord_6, TPathParams_4>(recordType: new () => TRecord_6, resourceEndpoint: string): UpdateServiceHook<TRecord_6, TPathParams_4>;
};
export { ServiceHookFactory };
